@@ -5,15 +5,16 @@ NULL
 
 setMethod(
   f = "initialize", signature = "Folder",
-  definition = function(.Object, ssimObject, folder, parentFolder = NULL, create = FALSE) {
-    Name <- NULL
-    FolderID <- NULL
+  definition = function(.Object, ssimObject, folder, parentFolder = NULL, 
+                        summary = FALSE, create = FALSE) {
     
+    Name <- NULL
+    FolderId <- NULL
+    ProjectId <- NULL
     x <- ssimObject
     
-    # Set some defaults
-    ProjectID <- x@projectId
-    ParentID <- 0
+    # Set default parent ID
+    ParentId <- 0
     
     # Depending on whether x is a ssimLibrary or Project, grab corresponding folder data
     folders <- getFolderData(x)
@@ -22,6 +23,7 @@ setMethod(
     # Get folder name and validate
     if (is.character(folder)){
       folders <- subset(folders, Name == folder)
+      folders <- subset(folders, ProjectId == x@projectId)
       
       # If more than 1 folder retrieved, then name is not unique
       if ((nrow(folders) > 1) & (create == FALSE)) {
@@ -32,7 +34,7 @@ setMethod(
 
     } else if (is.numeric(folder)){
       
-      folders <- subset(folders, FolderID == folder)
+      folders <- subset(folders, FolderId == folder)
       
       # If no folders retrieved, then ID does not yet exist
       if (nrow(folders) == 0){
@@ -53,11 +55,11 @@ setMethod(
 
     # If one folder retrieved, then open folder
     if ((nrow(folders) == 1) & (create == FALSE)) {
-      .Object@folderId <- folders$FolderID
-      .Object@parentId <- getParentFolderId(x, folders$FolderID)
+      .Object@folderId <- folders$FolderId
+      .Object@parentId <- getParentFolderId(x, folders$FolderId)
       .Object@session <- .session(x)
       .Object@filepath <- .filepath(x)
-      .Object@projectId <- ProjectID
+      .Object@projectId <- x@projectId
       return(.Object)
     }
     
@@ -66,7 +68,7 @@ setMethod(
       
       # Grab parent folder ID and validate inputs
       if (is(parentFolder, "Folder")) {
-        ParentID <- parentFolder@folderId 
+        ParentId <- parentFolder@folderId 
         
       } else if (is.character(parentFolder)) {
         parentFolderData <- subset(allFolders, Name == parentFolder)
@@ -77,10 +79,10 @@ setMethod(
                       ". Please provide a valid parent folder name."))
         }
         
-        ParentID <- parentFolderData$FolderID
+        ParentId <- parentFolderData$FolderId
         
       } else if (is.numeric(parentFolder)) {
-        parentFolderData <- subset(allFolders, FolderID == parentFolder)
+        parentFolderData <- subset(allFolders, FolderId == parentFolder)
         
         if (nrow(parentFolderData) == 0) {
           stop(paste0("The library does not contain a folder with the ID ", 
@@ -88,7 +90,7 @@ setMethod(
                       ". Please provide a valid parent folder ID"))
         }
         
-        ParentID <- parentFolderData$FolderID
+        ParentId <- parentFolderData$FolderId
         
       } else {
         stop("The parentFolder argument must be a character, integer, or SyncroSim folder object.")
@@ -96,9 +98,9 @@ setMethod(
       
       # Create nested folder
       args <- list(lib = .filepath(x), create = NULL, folder = NULL, 
-                   name = Name, tfid = ParentID)
+                   name = Name, tfid = ParentId)
       tt <- command(args = args, session = .session(x))
-      FolderID <- as.integer(strsplit(tt, ": ")[[1]][2])
+      FolderId <- as.integer(strsplit(tt, ": ")[[1]][2])
       
     } else {
       
@@ -108,16 +110,16 @@ setMethod(
       }
       
       args <- list(lib = .filepath(x), create = NULL, folder = NULL, 
-                   name = Name, tpid = ProjectID)
+                   name = Name, tpid = x@projectId)
       tt <- command(args = args, session = .session(x))
-      FolderID <- as.integer(strsplit(tt, ": ")[[1]][2])
+      FolderId <- as.integer(strsplit(tt, ": ")[[1]][2])
     }
     
-    .Object@folderId <- FolderID
-    .Object@parentId <- getParentFolderId(x, FolderID)
+    .Object@folderId <- FolderId
+    .Object@parentId <- getParentFolderId(x, FolderId)
     .Object@session <- .session(x)
     .Object@filepath <- .filepath(x)
-    .Object@projectId <- ProjectID
+    .Object@projectId <- x@projectId
     return(.Object)
   }
 )
@@ -136,6 +138,9 @@ setMethod(
 #' @param parentFolder character, integer, or SyncroSim Folder object. If not 
 #' \code{NULL} (Default), the new folder will be created inside of the
 #' specified parent folder
+#' @param summary logical. If \code{FALSE}, then returns a folder object. If 
+#' \code{TRUE}, then returns a dataframe of information about the specified
+#' folder
 #' @param create logical. Whether to create a new folder if the folder name given
 #' already exists in the SyncroSim library. If \code{FALSE} (Default), then will 
 #' return the existing folder with the given name. If \code{TRUE}, then will
@@ -162,11 +167,15 @@ setMethod(
 #' # Create a nested folder within "New Folder"
 #' myNestedFolder <- folder(myProject, folder = "New Nested Folder", 
 #'                          parentFolder = myFolder)
+#'                          
+#' # Retrieve a dataframe of all folders in a project
+#' folder(myProject)
 #' }
 #' 
 #' @name folder
 #' @export
-folder <- function(ssimObject = NULL, folder = NULL, parentFolder = NULL, create = FALSE) {
+folder <- function(ssimObject = NULL, folder = NULL, parentFolder = NULL, 
+                   summary = FALSE, create = FALSE) {
   if (is.character(ssimObject) && (ssimObject == SyncroSimNotFound(warn = FALSE))) {
     return(SyncroSimNotFound())
   }
@@ -176,15 +185,25 @@ folder <- function(ssimObject = NULL, folder = NULL, parentFolder = NULL, create
     stop("Cannot create a folder at the Scenario-level.")
   }
   
+  FolderId <- NULL
+  Name <- NULL
+  
+  x <- ssimObject
+  
+  if (is(ssimObject, "Folder") & (summary == TRUE)){
+    x <- .project(filepath(ssimObject), project = .projectId(ssimObject))
+  }
+  
   # Return folder data if no folder argument is specified
-  if (is.null(folder)){
-    folders <- getFolderData(ssimObject)
+  if (is.null(folder) | summary == TRUE){
     
-    if (is(ssimObject, "Project")){
+    folders <- getFolderData(x)
+    
+    if (is(x, "Project")){
       # Filter for folders in the project
-      pid <- .projectId(ssimObject)
-      df <- getLibraryStructure(ssimObject)
-      projInd <- which(df$id == pid)
+      pid <- .projectId(x)
+      df <- getLibraryStructure(x)
+      projInd <- which((df$id == pid) & (df$item == "Project"))
       projRow <- df[projInd, ]
       childInd <- projInd + 1
       childRow <- df[childInd, ]
@@ -205,7 +224,18 @@ folder <- function(ssimObject = NULL, folder = NULL, parentFolder = NULL, create
         }
       }
       
-      folders <- folders[which(folders$FolderID %in% ids), ]
+      folders <- folders[which(folders$FolderId %in% ids), ]
+    }
+    
+    # Subset dataframe by specified folder if summary == TRUE
+    if (is(ssimObject, "Folder") & (summary == TRUE)){
+      folders <- subset(folders, FolderId == .folderId(ssimObject))
+    } else if (!is.null(folder) & (summary == TRUE)){
+      if (is.numeric(folder)) {
+        folders <- subset(folders, FolderId == folder)
+      } else {
+        folders <- subset(folders, Name == folder)
+      }
     }
     
     return(folders)
